@@ -14,6 +14,8 @@ if not settings.configured:
         INSTALLED_APPS = (
             'modeltranslation_wrapper',
         ),
+        # This is necessary since modeltranslation-0.4 enforces some value (bug reported)
+        MODELTRANSLATION_TRANSLATION_FILES = ('modeltranslation_wrapper.tests.nothing',),
     )
 
 call_command('test', 'modeltranslation_wrapper')
